# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from ranking import Gs2RankingRestClient, request as request_, result as result_
from ranking.domain.iterator.namespaces import DescribeNamespacesIterator
from ranking.domain.cache.namespace import NamespaceDomainCache
from ranking.domain.cache.subscribe_user import SubscribeUserDomainCache
from ranking.domain.namespace import NamespaceDomain

class Gs2Ranking:
    _session: Gs2RestSession
    _client: Gs2RankingRestClient
    _namespace_cache: NamespaceDomainCache
    _subscribeUser_cache: SubscribeUserDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
    ):
        self._session = session
        self._client = Gs2RankingRestClient (
            session,
        )
        self._namespace_cache = NamespaceDomainCache()
        self._subscribeUser_cache = SubscribeUserDomainCache()

    def create_namespace(
        self,
        request: request_.CreateNamespaceRequest,
    ) -> result_.CreateNamespaceResult:
        r = self._client.create_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def calc_ranking(
        self,
        request: request_.CalcRankingRequest,
    ) -> result_.CalcRankingResult:
        r = self._client.calc_ranking(
            request,
        )
        return r

    def namespaces(
        self,
    ) -> DescribeNamespacesIterator:
        return DescribeNamespacesIterator(
            self._namespace_cache,
            self._client,
        )

    def namespace(
        self,
        namespace_name: str,
    ) -> NamespaceDomain:
        return NamespaceDomain(
            self._session,
            self._namespace_cache,
            namespace_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from log import Gs2LogRestClient, request as request_, result as result_
from log.domain.iterator.namespaces import DescribeNamespacesIterator
from log.domain.cache.namespace import NamespaceDomainCache


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2LogRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2LogRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def query_access_log(
        self,
        request: request_.QueryAccessLogRequest,
    ) -> result_.QueryAccessLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.query_access_log(
            request,
        )
        return r

    def count_access_log(
        self,
        request: request_.CountAccessLogRequest,
    ) -> result_.CountAccessLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.count_access_log(
            request,
        )
        return r

    def query_issue_stamp_sheet_log(
        self,
        request: request_.QueryIssueStampSheetLogRequest,
    ) -> result_.QueryIssueStampSheetLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.query_issue_stamp_sheet_log(
            request,
        )
        return r

    def count_issue_stamp_sheet_log(
        self,
        request: request_.CountIssueStampSheetLogRequest,
    ) -> result_.CountIssueStampSheetLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.count_issue_stamp_sheet_log(
            request,
        )
        return r

    def query_execute_stamp_sheet_log(
        self,
        request: request_.QueryExecuteStampSheetLogRequest,
    ) -> result_.QueryExecuteStampSheetLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.query_execute_stamp_sheet_log(
            request,
        )
        return r

    def count_execute_stamp_sheet_log(
        self,
        request: request_.CountExecuteStampSheetLogRequest,
    ) -> result_.CountExecuteStampSheetLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.count_execute_stamp_sheet_log(
            request,
        )
        return r

    def query_execute_stamp_task_log(
        self,
        request: request_.QueryExecuteStampTaskLogRequest,
    ) -> result_.QueryExecuteStampTaskLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.query_execute_stamp_task_log(
            request,
        )
        return r

    def count_execute_stamp_task_log(
        self,
        request: request_.CountExecuteStampTaskLogRequest,
    ) -> result_.CountExecuteStampTaskLogResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.count_execute_stamp_task_log(
            request,
        )
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from lottery import Gs2LotteryRestClient, request as request_, result as result_
from lottery.domain.iterator.namespaces import DescribeNamespacesIterator
from lottery.domain.iterator.lottery_model_masters import DescribeLotteryModelMastersIterator
from lottery.domain.iterator.prize_table_masters import DescribePrizeTableMastersIterator
from lottery.domain.iterator.boxes import DescribeBoxesIterator
from lottery.domain.iterator.boxes_by_user_id import DescribeBoxesByUserIdIterator
from lottery.domain.iterator.lottery_models import DescribeLotteryModelsIterator
from lottery.domain.iterator.prize_tables import DescribePrizeTablesIterator
from lottery.domain.iterator.probabilities import DescribeProbabilitiesIterator
from lottery.domain.iterator.probabilities_by_user_id import DescribeProbabilitiesByUserIdIterator
from lottery.domain.cache.namespace import NamespaceDomainCache
from lottery.domain.cache.lottery_model_master import LotteryModelMasterDomainCache
from lottery.domain.cache.prize_table_master import PrizeTableMasterDomainCache
from lottery.domain.cache.box import BoxDomainCache
from lottery.domain.cache.lottery_model import LotteryModelDomainCache
from lottery.domain.cache.prize_table import PrizeTableDomainCache
from lottery.domain.cache.probability import ProbabilityDomainCache
from lottery.domain.box import BoxDomain
from lottery.domain.box_access_token import BoxAccessTokenDomain
from lottery.domain.box_access_token import BoxAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2LotteryRestClient
    _namespace_name: str
    _access_token: AccessToken
    _box_cache: BoxDomainCache
    _probability_cache: ProbabilityDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2LotteryRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._box_cache = BoxDomainCache()
        self._probability_cache = ProbabilityDomainCache()

    def boxes(
        self,
    ) -> DescribeBoxesIterator:
        return DescribeBoxesIterator(
            self._box_cache,
            self._client,
            self._namespace_name,
            self._access_token,
        )

    def probabilities(
        self,
        lottery_name: str,
    ) -> DescribeProbabilitiesIterator:
        return DescribeProbabilitiesIterator(
            self._probability_cache,
            self._client,
            self._namespace_name,
            lottery_name,
            self._access_token,
        )

    def box(
        self,
        prize_table_name: str,
    ) -> BoxAccessTokenDomain:
        return BoxAccessTokenDomain(
            self._session,
            self._box_cache,
            self._namespace_name,
            self._access_token,
            prize_table_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from ranking.domain.service import *
from ranking.domain.namespace import *
from ranking.domain.category_model import *
from ranking.domain.category_model_master import *
from ranking.domain.subscribe import *
from ranking.domain.subscribe_access_token import *
from ranking.domain.subscribe import *
from ranking.domain.subscribe_access_token import *
from ranking.domain.score import *
from ranking.domain.score_access_token import *
from ranking.domain.score import *
from ranking.domain.score_access_token import *
from ranking.domain.ranking import *
from ranking.domain.ranking_access_token import *
from ranking.domain.ranking import *
from ranking.domain.ranking_access_token import *
from ranking.domain.current_ranking_master import *
from ranking.domain.user import *
from ranking.domain.user_access_token import *
from ranking.domain.user import *
from ranking.domain.user_access_token import *
from ranking.domain.iterator.namespaces import *
from ranking.domain.iterator.category_models import *
from ranking.domain.iterator.category_model_masters import *
from ranking.domain.iterator.subscribes_by_category_name import *
from ranking.domain.iterator.subscribes_by_category_name_and_user_id import *
from ranking.domain.iterator.scores import *
from ranking.domain.iterator.scores_by_user_id import *
from ranking.domain.iterator.rankings import *
from ranking.domain.iterator.rankings_by_user_id import *
from ranking.domain.iterator.near_rankings import *
from ranking.domain.cache.namespace import *
from ranking.domain.cache.category_model import *
from ranking.domain.cache.category_model_master import *
from ranking.domain.cache.subscribe_user import *
from ranking.domain.cache.score import *
from ranking.domain.cache.ranking import *


# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from account import * as account
from auth import * as auth
from chat import * as chat
from core import * as core
from datastore import * as datastore
from deploy import * as deploy
from dictionary import * as dictionary
from distributor import * as distributor
from enhance import * as enhance
from exchange import * as exchange
from formation import * as formation
from experience import * as experience
from formation import * as formation
from friend import * as friend
from gateway import * as gateway
from identifier import * as identifier
from inbox import * as inbox
from inventory import * as inventory
from job_queue import * as job_queue
from key import * as key
from limit import * as limit
from lock import * as lock
from log import * as log
from lottery import * as lottery
from matchmaking import * as matchmaking
from mission import * as mission
from money import * as money
from news import * as news
from project import * as project
from quest import * as quest
from ranking import * as ranking
from realtime import * as realtime
from schedule import * as schedule
from script import * as script
from showcase import * as showcase
from stamina import * as stamina
from version import * as version
from watch import * as watch




# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from ranking import Gs2RankingRestClient, request as request_, result as result_
from ranking.domain.iterator.namespaces import DescribeNamespacesIterator
from ranking.domain.iterator.category_models import DescribeCategoryModelsIterator
from ranking.domain.iterator.category_model_masters import DescribeCategoryModelMastersIterator
from ranking.domain.iterator.subscribes_by_category_name import DescribeSubscribesByCategoryNameIterator
from ranking.domain.iterator.subscribes_by_category_name_and_user_id import DescribeSubscribesByCategoryNameAndUserIdIterator
from ranking.domain.iterator.scores import DescribeScoresIterator
from ranking.domain.iterator.scores_by_user_id import DescribeScoresByUserIdIterator
from ranking.domain.iterator.rankings import DescribeRankingsIterator
from ranking.domain.iterator.rankings_by_user_id import DescribeRankingsByUserIdIterator
from ranking.domain.iterator.near_rankings import DescribeNearRankingsIterator
from ranking.domain.cache.namespace import NamespaceDomainCache
from ranking.domain.cache.category_model import CategoryModelDomainCache
from ranking.domain.cache.category_model_master import CategoryModelMasterDomainCache
from ranking.domain.cache.subscribe_user import SubscribeUserDomainCache
from ranking.domain.cache.score import ScoreDomainCache
from ranking.domain.cache.ranking import RankingDomainCache


class ScoreDomain:
    _session: Gs2RestSession
    _client: Gs2RankingRestClient
    _score_cache: ScoreDomainCache
    _namespace_name: str
    _user_id: str
    _category_name: str
    _scorer_user_id: str
    _unique_id: str

    def __init__(
        self,
        session: Gs2RestSession,
        score_cache: ScoreDomainCache,
        namespace_name: str,
        user_id: str,
        category_name: str,
        scorer_user_id: str,
        unique_id: str,
    ):
        self._session = session
        self._client = Gs2RankingRestClient(
            session,
        )
        self._score_cache = score_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._category_name = category_name
        self._scorer_user_id = scorer_user_id
        self._unique_id = unique_id

    def load(
        self,
        request: request_.GetScoreByUserIdRequest,
    ) -> result_.GetScoreByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_category_name(self._category_name)
        request.with_scorer_user_id(self._scorer_user_id)
        request.with_unique_id(self._unique_id)
        r = self._client.get_score_by_user_id(
            request,
        )
        self._score_cache.update(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from schedule import Gs2ScheduleRestClient, request as request_, result as result_
from schedule.domain.iterator.namespaces import DescribeNamespacesIterator
from schedule.domain.iterator.event_masters import DescribeEventMastersIterator
from schedule.domain.iterator.triggers import DescribeTriggersIterator
from schedule.domain.iterator.triggers_by_user_id import DescribeTriggersByUserIdIterator
from schedule.domain.iterator.events import DescribeEventsIterator
from schedule.domain.iterator.events_by_user_id import DescribeEventsByUserIdIterator
from schedule.domain.iterator.raw_events import DescribeRawEventsIterator
from schedule.domain.cache.namespace import NamespaceDomainCache
from schedule.domain.cache.event_master import EventMasterDomainCache
from schedule.domain.cache.trigger import TriggerDomainCache
from schedule.domain.cache.event import EventDomainCache
from schedule.domain.trigger import TriggerDomain
from schedule.domain.trigger_access_token import TriggerAccessTokenDomain
from schedule.domain.trigger_access_token import TriggerAccessTokenDomain
from schedule.domain.event import EventDomain
from schedule.domain.event_access_token import EventAccessTokenDomain
from schedule.domain.event_access_token import EventAccessTokenDomain


class UserDomain:
    _session: Gs2RestSession
    _client: Gs2ScheduleRestClient
    _namespace_name: str
    _user_id: str
    _trigger_cache: TriggerDomainCache
    _event_cache: EventDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2ScheduleRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._trigger_cache = TriggerDomainCache()
        self._event_cache = EventDomainCache()

    def triggers(
        self,
    ) -> DescribeTriggersByUserIdIterator:
        return DescribeTriggersByUserIdIterator(
            self._trigger_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )

    def events(
        self,
    ) -> DescribeEventsByUserIdIterator:
        return DescribeEventsByUserIdIterator(
            self._event_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )

    def raw_events(
        self,
    ) -> DescribeRawEventsIterator:
        return DescribeRawEventsIterator(
            self._event_cache,
            self._client,
            self._namespace_name,
        )

    def trigger(
        self,
        trigger_name: str,
    ) -> TriggerDomain:
        return TriggerDomain(
            self._session,
            self._trigger_cache,
            self._namespace_name,
            self._user_id,
            trigger_name,
        )

    def event(
        self,
        event_name: str,
    ) -> EventDomain:
        return EventDomain(
            self._session,
            self._event_cache,
            self._namespace_name,
            self._user_id,
            event_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from inbox import Gs2InboxRestClient, request as request_, result as result_
from inbox.domain.iterator.namespaces import DescribeNamespacesIterator
from inbox.domain.iterator.messages import DescribeMessagesIterator
from inbox.domain.iterator.messages_by_user_id import DescribeMessagesByUserIdIterator
from inbox.domain.iterator.global_message_masters import DescribeGlobalMessageMastersIterator
from inbox.domain.iterator.global_messages import DescribeGlobalMessagesIterator
from inbox.domain.cache.namespace import NamespaceDomainCache
from inbox.domain.cache.message import MessageDomainCache
from inbox.domain.cache.global_message_master import GlobalMessageMasterDomainCache
from inbox.domain.cache.global_message import GlobalMessageDomainCache


class GlobalMessageMasterDomain:
    _session: Gs2RestSession
    _client: Gs2InboxRestClient
    _global_message_master_cache: GlobalMessageMasterDomainCache
    _namespace_name: str
    _global_message_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        global_message_master_cache: GlobalMessageMasterDomainCache,
        namespace_name: str,
        global_message_name: str,
    ):
        self._session = session
        self._client = Gs2InboxRestClient(
            session,
        )
        self._global_message_master_cache = global_message_master_cache
        self._namespace_name = namespace_name
        self._global_message_name = global_message_name

    def load(
        self,
        request: request_.GetGlobalMessageMasterRequest,
    ) -> result_.GetGlobalMessageMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_global_message_name(self._global_message_name)
        r = self._client.get_global_message_master(
            request,
        )
        self._global_message_master_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateGlobalMessageMasterRequest,
    ) -> result_.UpdateGlobalMessageMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_global_message_name(self._global_message_name)
        r = self._client.update_global_message_master(
            request,
        )
        self._global_message_master_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteGlobalMessageMasterRequest,
    ) -> result_.DeleteGlobalMessageMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_global_message_name(self._global_message_name)
        r = self._client.delete_global_message_master(
            request,
        )
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from matchmaking import Gs2MatchmakingRestClient, request as request_, result as result_
from matchmaking.domain.iterator.namespaces import DescribeNamespacesIterator
from matchmaking.domain.iterator.gatherings import DescribeGatheringsIterator
from matchmaking.domain.iterator.rating_model_masters import DescribeRatingModelMastersIterator
from matchmaking.domain.iterator.rating_models import DescribeRatingModelsIterator
from matchmaking.domain.iterator.ratings import DescribeRatingsIterator
from matchmaking.domain.iterator.ratings_by_user_id import DescribeRatingsByUserIdIterator
from matchmaking.domain.cache.namespace import NamespaceDomainCache
from matchmaking.domain.cache.gathering import GatheringDomainCache
from matchmaking.domain.cache.rating_model_master import RatingModelMasterDomainCache
from matchmaking.domain.cache.rating_model import RatingModelDomainCache
from matchmaking.domain.cache.rating import RatingDomainCache
from matchmaking.domain.user import UserDomain
from matchmaking.domain.user_access_token import UserAccessTokenDomain
from matchmaking.domain.user_access_token import UserAccessTokenDomain
from matchmaking.domain.current_rating_model_master import CurrentRatingModelMasterDomain
from matchmaking.domain.rating_model import RatingModelDomain
from matchmaking.domain.rating_model_master import RatingModelMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2MatchmakingRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _rating_model_master_cache: RatingModelMasterDomainCache
    _rating_model_cache: RatingModelDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2MatchmakingRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._rating_model_master_cache = RatingModelMasterDomainCache()
        self._rating_model_cache = RatingModelDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_rating_model_master(
        self,
        request: request_.CreateRatingModelMasterRequest,
    ) -> result_.CreateRatingModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_rating_model_master(
            request,
        )
        return r

    def rating_model_masters(
        self,
    ) -> DescribeRatingModelMastersIterator:
        return DescribeRatingModelMastersIterator(
            self._rating_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def rating_models(
        self,
    ) -> DescribeRatingModelsIterator:
        return DescribeRatingModelsIterator(
            self._rating_model_cache,
            self._client,
            self._namespace_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def current_rating_model_master(
        self,
    ) -> CurrentRatingModelMasterDomain:
        return CurrentRatingModelMasterDomain(
            self._session,
            self._namespace_name,
        )

    def rating_model(
        self,
        rating_name: str,
    ) -> RatingModelDomain:
        return RatingModelDomain(
            self._session,
            self._rating_model_cache,
            self._namespace_name,
            rating_name,
        )

    def rating_model_master(
        self,
        rating_name: str,
    ) -> RatingModelMasterDomain:
        return RatingModelMasterDomain(
            self._session,
            self._rating_model_master_cache,
            self._namespace_name,
            rating_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from mission import Gs2MissionRestClient, request as request_, result as result_
from mission.domain.iterator.completes import DescribeCompletesIterator
from mission.domain.iterator.completes_by_user_id import DescribeCompletesByUserIdIterator
from mission.domain.iterator.counter_model_masters import DescribeCounterModelMastersIterator
from mission.domain.iterator.mission_group_model_masters import DescribeMissionGroupModelMastersIterator
from mission.domain.iterator.namespaces import DescribeNamespacesIterator
from mission.domain.iterator.counters import DescribeCountersIterator
from mission.domain.iterator.counters_by_user_id import DescribeCountersByUserIdIterator
from mission.domain.iterator.counter_models import DescribeCounterModelsIterator
from mission.domain.iterator.mission_group_models import DescribeMissionGroupModelsIterator
from mission.domain.iterator.mission_task_models import DescribeMissionTaskModelsIterator
from mission.domain.iterator.mission_task_model_masters import DescribeMissionTaskModelMastersIterator
from mission.domain.cache.complete import CompleteDomainCache
from mission.domain.cache.counter_model_master import CounterModelMasterDomainCache
from mission.domain.cache.mission_group_model_master import MissionGroupModelMasterDomainCache
from mission.domain.cache.namespace import NamespaceDomainCache
from mission.domain.cache.counter import CounterDomainCache
from mission.domain.cache.counter_model import CounterModelDomainCache
from mission.domain.cache.mission_group_model import MissionGroupModelDomainCache
from mission.domain.cache.mission_task_model import MissionTaskModelDomainCache
from mission.domain.cache.mission_task_model_master import MissionTaskModelMasterDomainCache
from mission.domain.current_mission_master import CurrentMissionMasterDomain
from mission.domain.mission_group_model import MissionGroupModelDomain
from mission.domain.counter_model import CounterModelDomain
from mission.domain.user import UserDomain
from mission.domain.user_access_token import UserAccessTokenDomain
from mission.domain.user_access_token import UserAccessTokenDomain
from mission.domain.mission_group_model_master import MissionGroupModelMasterDomain
from mission.domain.counter_model_master import CounterModelMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2MissionRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _counter_model_master_cache: CounterModelMasterDomainCache
    _mission_group_model_master_cache: MissionGroupModelMasterDomainCache
    _counter_model_cache: CounterModelDomainCache
    _mission_group_model_cache: MissionGroupModelDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2MissionRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._counter_model_master_cache = CounterModelMasterDomainCache()
        self._mission_group_model_master_cache = MissionGroupModelMasterDomainCache()
        self._counter_model_cache = CounterModelDomainCache()
        self._mission_group_model_cache = MissionGroupModelDomainCache()

    def create_counter_model_master(
        self,
        request: request_.CreateCounterModelMasterRequest,
    ) -> result_.CreateCounterModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_counter_model_master(
            request,
        )
        return r

    def create_mission_group_model_master(
        self,
        request: request_.CreateMissionGroupModelMasterRequest,
    ) -> result_.CreateMissionGroupModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_mission_group_model_master(
            request,
        )
        return r

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def counter_model_masters(
        self,
    ) -> DescribeCounterModelMastersIterator:
        return DescribeCounterModelMastersIterator(
            self._counter_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def mission_group_model_masters(
        self,
    ) -> DescribeMissionGroupModelMastersIterator:
        return DescribeMissionGroupModelMastersIterator(
            self._mission_group_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def counter_models(
        self,
    ) -> DescribeCounterModelsIterator:
        return DescribeCounterModelsIterator(
            self._counter_model_cache,
            self._client,
            self._namespace_name,
        )

    def mission_group_models(
        self,
    ) -> DescribeMissionGroupModelsIterator:
        return DescribeMissionGroupModelsIterator(
            self._mission_group_model_cache,
            self._client,
            self._namespace_name,
        )

    def current_mission_master(
        self,
    ) -> CurrentMissionMasterDomain:
        return CurrentMissionMasterDomain(
            self._session,
            self._namespace_name,
        )

    def mission_group_model(
        self,
        mission_group_name: str,
    ) -> MissionGroupModelDomain:
        return MissionGroupModelDomain(
            self._session,
            self._mission_group_model_cache,
            self._namespace_name,
            mission_group_name,
        )

    def counter_model(
        self,
        counter_name: str,
    ) -> CounterModelDomain:
        return CounterModelDomain(
            self._session,
            self._counter_model_cache,
            self._namespace_name,
            counter_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def mission_group_model_master(
        self,
        mission_group_name: str,
    ) -> MissionGroupModelMasterDomain:
        return MissionGroupModelMasterDomain(
            self._session,
            self._mission_group_model_master_cache,
            self._namespace_name,
            mission_group_name,
        )

    def counter_model_master(
        self,
        counter_name: str,
    ) -> CounterModelMasterDomain:
        return CounterModelMasterDomain(
            self._session,
            self._counter_model_master_cache,
            self._namespace_name,
            counter_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from schedule import Gs2ScheduleRestClient, request as request_, result as result_
from schedule.domain.iterator.namespaces import DescribeNamespacesIterator
from schedule.domain.iterator.event_masters import DescribeEventMastersIterator
from schedule.domain.iterator.triggers import DescribeTriggersIterator
from schedule.domain.iterator.triggers_by_user_id import DescribeTriggersByUserIdIterator
from schedule.domain.iterator.events import DescribeEventsIterator
from schedule.domain.iterator.events_by_user_id import DescribeEventsByUserIdIterator
from schedule.domain.iterator.raw_events import DescribeRawEventsIterator
from schedule.domain.cache.namespace import NamespaceDomainCache
from schedule.domain.cache.event_master import EventMasterDomainCache
from schedule.domain.cache.trigger import TriggerDomainCache
from schedule.domain.cache.event import EventDomainCache


class EventAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2ScheduleRestClient
    _event_cache: EventDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _event_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        event_cache: EventDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        event_name: str,
    ):
        self._session = session
        self._client = Gs2ScheduleRestClient(
            session,
        )
        self._event_cache = event_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._event_name = event_name

    def load(
        self,
        request: request_.GetEventRequest,
    ) -> result_.GetEventResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_event_name(self._event_name)
        r = self._client.get_event(
            request,
        )
        self._event_cache.update(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from money import Gs2MoneyRestClient, request as request_, result as result_
from money.domain.iterator.namespaces import DescribeNamespacesIterator
from money.domain.iterator.wallets import DescribeWalletsIterator
from money.domain.iterator.wallets_by_user_id import DescribeWalletsByUserIdIterator
from money.domain.iterator.receipts import DescribeReceiptsIterator
from money.domain.cache.namespace import NamespaceDomainCache
from money.domain.cache.wallet import WalletDomainCache
from money.domain.cache.receipt import ReceiptDomainCache
from money.domain.wallet import WalletDomain
from money.domain.wallet_access_token import WalletAccessTokenDomain
from money.domain.wallet_access_token import WalletAccessTokenDomain
from money.domain.receipt import ReceiptDomain
from money.domain.receipt_access_token import ReceiptAccessTokenDomain
from money.domain.receipt_access_token import ReceiptAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2MoneyRestClient
    _namespace_name: str
    _access_token: AccessToken
    _wallet_cache: WalletDomainCache
    _receipt_cache: ReceiptDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2MoneyRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._wallet_cache = WalletDomainCache()
        self._receipt_cache = ReceiptDomainCache()

    def wallets(
        self,
    ) -> DescribeWalletsIterator:
        return DescribeWalletsIterator(
            self._wallet_cache,
            self._client,
            self._namespace_name,
            self._access_token,
        )

    def wallet(
        self,
        slot: int,
    ) -> WalletAccessTokenDomain:
        return WalletAccessTokenDomain(
            self._session,
            self._wallet_cache,
            self._namespace_name,
            self._access_token,
            slot,
        )

    def receipt(
        self,
        transaction_id: str,
    ) -> ReceiptAccessTokenDomain:
        return ReceiptAccessTokenDomain(
            self._session,
            self._receipt_cache,
            self._namespace_name,
            self._access_token,
            transaction_id,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from inbox import Gs2InboxRestClient, request as request_, result as result_
from inbox.domain.iterator.namespaces import DescribeNamespacesIterator
from inbox.domain.iterator.messages import DescribeMessagesIterator
from inbox.domain.iterator.messages_by_user_id import DescribeMessagesByUserIdIterator
from inbox.domain.iterator.global_message_masters import DescribeGlobalMessageMastersIterator
from inbox.domain.iterator.global_messages import DescribeGlobalMessagesIterator
from inbox.domain.cache.namespace import NamespaceDomainCache
from inbox.domain.cache.message import MessageDomainCache
from inbox.domain.cache.global_message_master import GlobalMessageMasterDomainCache
from inbox.domain.cache.global_message import GlobalMessageDomainCache
from inbox.domain.message import MessageDomain
from inbox.domain.message_access_token import MessageAccessTokenDomain
from inbox.domain.message_access_token import MessageAccessTokenDomain
from inbox.domain.received import ReceivedDomain
from inbox.domain.received_access_token import ReceivedAccessTokenDomain
from inbox.domain.received_access_token import ReceivedAccessTokenDomain


class UserDomain:
    _session: Gs2RestSession
    _client: Gs2InboxRestClient
    _namespace_name: str
    _user_id: str
    _message_cache: MessageDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2InboxRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._message_cache = MessageDomainCache()

    def send_message(
        self,
        request: request_.SendMessageByUserIdRequest,
    ) -> result_.SendMessageByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.send_message_by_user_id(
            request,
        )
        return r

    def receive_global_message(
        self,
        request: request_.ReceiveGlobalMessageByUserIdRequest,
    ) -> result_.ReceiveGlobalMessageByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.receive_global_message_by_user_id(
            request,
        )
        return r

    def messages(
        self,
    ) -> DescribeMessagesByUserIdIterator:
        return DescribeMessagesByUserIdIterator(
            self._message_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )

    def message(
        self,
        message_name: str,
    ) -> MessageDomain:
        return MessageDomain(
            self._session,
            self._message_cache,
            self._namespace_name,
            self._user_id,
            message_name,
        )

    def received(
        self,
    ) -> ReceivedDomain:
        return ReceivedDomain(
            self._session,
            self._namespace_name,
            self._user_id,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from distributor import Gs2DistributorRestClient, request as request_, result as result_
from distributor.domain.iterator.namespaces import DescribeNamespacesIterator
from distributor.domain.iterator.distributor_model_masters import DescribeDistributorModelMastersIterator
from distributor.domain.iterator.distributor_models import DescribeDistributorModelsIterator
from distributor.domain.cache.namespace import NamespaceDomainCache
from distributor.domain.cache.distributor_model_master import DistributorModelMasterDomainCache
from distributor.domain.cache.distributor_model import DistributorModelDomainCache
from distributor.domain.current_distributor_master import CurrentDistributorMasterDomain
from distributor.domain.distributor_model import DistributorModelDomain
from distributor.domain.distributor_model_master import DistributorModelMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2DistributorRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _distributor_model_master_cache: DistributorModelMasterDomainCache
    _distributor_model_cache: DistributorModelDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2DistributorRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._distributor_model_master_cache = DistributorModelMasterDomainCache()
        self._distributor_model_cache = DistributorModelDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_distributor_model_master(
        self,
        request: request_.CreateDistributorModelMasterRequest,
    ) -> result_.CreateDistributorModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_distributor_model_master(
            request,
        )
        return r

    def distribute(
        self,
        request: request_.DistributeRequest,
    ) -> result_.DistributeResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.distribute(
            request,
        )
        return r

    def run_stamp_task(
        self,
        request: request_.RunStampTaskRequest,
    ) -> result_.RunStampTaskResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.run_stamp_task(
            request,
        )
        return r

    def run_stamp_sheet(
        self,
        request: request_.RunStampSheetRequest,
    ) -> result_.RunStampSheetResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.run_stamp_sheet(
            request,
        )
        return r

    def run_stamp_sheet_express(
        self,
        request: request_.RunStampSheetExpressRequest,
    ) -> result_.RunStampSheetExpressResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.run_stamp_sheet_express(
            request,
        )
        return r

    def distributor_model_masters(
        self,
    ) -> DescribeDistributorModelMastersIterator:
        return DescribeDistributorModelMastersIterator(
            self._distributor_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def distributor_models(
        self,
    ) -> DescribeDistributorModelsIterator:
        return DescribeDistributorModelsIterator(
            self._distributor_model_cache,
            self._client,
            self._namespace_name,
        )

    def current_distributor_master(
        self,
    ) -> CurrentDistributorMasterDomain:
        return CurrentDistributorMasterDomain(
            self._session,
            self._namespace_name,
        )

    def distributor_model(
        self,
        distributor_name: str,
    ) -> DistributorModelDomain:
        return DistributorModelDomain(
            self._session,
            self._distributor_model_cache,
            self._namespace_name,
            distributor_name,
        )

    def distributor_model_master(
        self,
        distributor_name: str,
    ) -> DistributorModelMasterDomain:
        return DistributorModelMasterDomain(
            self._session,
            self._distributor_model_master_cache,
            self._namespace_name,
            distributor_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from job_queue import Gs2JobQueueRestClient, request as request_, result as result_
from job_queue.domain.iterator.namespaces import DescribeNamespacesIterator
from job_queue.domain.iterator.jobs_by_user_id import DescribeJobsByUserIdIterator
from job_queue.domain.iterator.dead_letter_jobs_by_user_id import DescribeDeadLetterJobsByUserIdIterator
from job_queue.domain.cache.namespace import NamespaceDomainCache
from job_queue.domain.cache.job import JobDomainCache
from job_queue.domain.cache.dead_letter_job import DeadLetterJobDomainCache


class JobAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2JobQueueRestClient
    _job_cache: JobDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _job_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        job_cache: JobDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        job_name: str,
    ):
        self._session = session
        self._client = Gs2JobQueueRestClient(
            session,
        )
        self._job_cache = job_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._job_name = job_name



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from script import Gs2ScriptRestClient, request as request_, result as result_
from script.domain.iterator.namespaces import DescribeNamespacesIterator
from script.domain.iterator.scripts import DescribeScriptsIterator
from script.domain.cache.namespace import NamespaceDomainCache
from script.domain.cache.script import ScriptDomainCache
from script.domain.script import ScriptDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2ScriptRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _script_cache: ScriptDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2ScriptRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._script_cache = ScriptDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        return r

    def create_script(
        self,
        request: request_.CreateScriptRequest,
    ) -> result_.CreateScriptResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_script(
            request,
        )
        return r

    def create_script_from_git_hub(
        self,
        request: request_.CreateScriptFromGitHubRequest,
    ) -> result_.CreateScriptFromGitHubResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_script_from_git_hub(
            request,
        )
        return r

    def scripts(
        self,
    ) -> DescribeScriptsIterator:
        return DescribeScriptsIterator(
            self._script_cache,
            self._client,
            self._namespace_name,
        )

    def script(
        self,
        script_name: str,
    ) -> ScriptDomain:
        return ScriptDomain(
            self._session,
            self._script_cache,
            self._namespace_name,
            script_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from dictionary import Gs2DictionaryRestClient, request as request_, result as result_
from dictionary.domain.iterator.namespaces import DescribeNamespacesIterator
from dictionary.domain.iterator.entry_models import DescribeEntryModelsIterator
from dictionary.domain.iterator.entry_model_masters import DescribeEntryModelMastersIterator
from dictionary.domain.iterator.entries import DescribeEntriesIterator
from dictionary.domain.iterator.entries_by_user_id import DescribeEntriesByUserIdIterator
from dictionary.domain.cache.namespace import NamespaceDomainCache
from dictionary.domain.cache.entry_model import EntryModelDomainCache
from dictionary.domain.cache.entry_model_master import EntryModelMasterDomainCache
from dictionary.domain.cache.entry import EntryDomainCache


class EntryDomain:
    _session: Gs2RestSession
    _client: Gs2DictionaryRestClient
    _entry_cache: EntryDomainCache
    _namespace_name: str
    _user_id: str
    _entry_model_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        entry_cache: EntryDomainCache,
        namespace_name: str,
        user_id: str,
        entry_model_name: str,
    ):
        self._session = session
        self._client = Gs2DictionaryRestClient(
            session,
        )
        self._entry_cache = entry_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._entry_model_name = entry_model_name

    def load(
        self,
        request: request_.GetEntryByUserIdRequest,
    ) -> result_.GetEntryByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_entry_model_name(self._entry_model_name)
        r = self._client.get_entry_by_user_id(
            request,
        )
        self._entry_cache.update(r.item)
        return r

    def get_with_signature(
        self,
        request: request_.GetEntryWithSignatureByUserIdRequest,
    ) -> result_.GetEntryWithSignatureByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_entry_model_name(self._entry_model_name)
        r = self._client.get_entry_with_signature_by_user_id(
            request,
        )
        self._entry_cache.update(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from datastore import Gs2DatastoreRestClient, request as request_, result as result_
from datastore.domain.iterator.namespaces import DescribeNamespacesIterator
from datastore.domain.iterator.data_objects import DescribeDataObjectsIterator
from datastore.domain.iterator.data_objects_by_user_id import DescribeDataObjectsByUserIdIterator
from datastore.domain.iterator.data_object_histories import DescribeDataObjectHistoriesIterator
from datastore.domain.iterator.data_object_histories_by_user_id import DescribeDataObjectHistoriesByUserIdIterator
from datastore.domain.cache.namespace import NamespaceDomainCache
from datastore.domain.cache.data_object import DataObjectDomainCache
from datastore.domain.cache.data_object_history import DataObjectHistoryDomainCache


class DataObjectHistoryAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2DatastoreRestClient
    _data_object_history_cache: DataObjectHistoryDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _data_object_name: str
    _generation: str

    def __init__(
        self,
        session: Gs2RestSession,
        data_object_history_cache: DataObjectHistoryDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        data_object_name: str,
        generation: str,
    ):
        self._session = session
        self._client = Gs2DatastoreRestClient(
            session,
        )
        self._data_object_history_cache = data_object_history_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._data_object_name = data_object_name
        self._generation = generation

    def load(
        self,
        request: request_.GetDataObjectHistoryRequest,
    ) -> result_.GetDataObjectHistoryResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_data_object_name(self._data_object_name)
        request.with_generation(self._generation)
        r = self._client.get_data_object_history(
            request,
        )
        self._data_object_history_cache.update(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from formation import Gs2FormationRestClient, request as request_, result as result_
from formation.domain.iterator.namespaces import DescribeNamespacesIterator
from formation.domain.iterator.form_model_masters import DescribeFormModelMastersIterator
from formation.domain.iterator.mold_models import DescribeMoldModelsIterator
from formation.domain.iterator.mold_model_masters import DescribeMoldModelMastersIterator
from formation.domain.iterator.molds import DescribeMoldsIterator
from formation.domain.iterator.molds_by_user_id import DescribeMoldsByUserIdIterator
from formation.domain.iterator.forms import DescribeFormsIterator
from formation.domain.iterator.forms_by_user_id import DescribeFormsByUserIdIterator
from formation.domain.cache.namespace import NamespaceDomainCache
from formation.domain.cache.form_model_master import FormModelMasterDomainCache
from formation.domain.cache.mold_model import MoldModelDomainCache
from formation.domain.cache.mold_model_master import MoldModelMasterDomainCache
from formation.domain.cache.mold import MoldDomainCache
from formation.domain.cache.form import FormDomainCache
from formation.domain.form import FormDomain
from formation.domain.form_access_token import FormAccessTokenDomain
from formation.domain.form_access_token import FormAccessTokenDomain


class MoldAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2FormationRestClient
    _mold_cache: MoldDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _mold_name: str
    _form_cache: FormDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        mold_cache: MoldDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        mold_name: str,
    ):
        self._session = session
        self._client = Gs2FormationRestClient(
            session,
        )
        self._mold_cache = mold_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._mold_name = mold_name
        self._form_cache = FormDomainCache()

    def load(
        self,
        request: request_.GetMoldRequest,
    ) -> result_.GetMoldResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_mold_name(self._mold_name)
        r = self._client.get_mold(
            request,
        )
        self._mold_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteMoldRequest,
    ) -> result_.DeleteMoldResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_mold_name(self._mold_name)
        r = self._client.delete_mold(
            request,
        )
        self._mold_cache.delete(r.item)
        return r

    def forms(
        self,
    ) -> DescribeFormsIterator:
        return DescribeFormsIterator(
            self._form_cache,
            self._client,
            self._namespace_name,
            self._mold_name,
            self._access_token,
        )

    def form(
        self,
        index: int,
    ) -> FormAccessTokenDomain:
        return FormAccessTokenDomain(
            self._session,
            self._form_cache,
            self._namespace_name,
            self._access_token,
            self._mold_name,
            index,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from showcase import Gs2ShowcaseRestClient, request as request_, result as result_
from showcase.domain.iterator.namespaces import DescribeNamespacesIterator
from showcase.domain.iterator.sales_item_masters import DescribeSalesItemMastersIterator
from showcase.domain.iterator.sales_item_group_masters import DescribeSalesItemGroupMastersIterator
from showcase.domain.iterator.showcase_masters import DescribeShowcaseMastersIterator
from showcase.domain.iterator.showcases import DescribeShowcasesIterator
from showcase.domain.iterator.showcases_by_user_id import DescribeShowcasesByUserIdIterator
from showcase.domain.cache.namespace import NamespaceDomainCache
from showcase.domain.cache.sales_item_master import SalesItemMasterDomainCache
from showcase.domain.cache.sales_item_group_master import SalesItemGroupMasterDomainCache
from showcase.domain.cache.showcase_master import ShowcaseMasterDomainCache
from showcase.domain.cache.showcase import ShowcaseDomainCache


class ShowcaseAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2ShowcaseRestClient
    _showcase_cache: ShowcaseDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _showcase_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        showcase_cache: ShowcaseDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        showcase_name: str,
    ):
        self._session = session
        self._client = Gs2ShowcaseRestClient(
            session,
        )
        self._showcase_cache = showcase_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._showcase_name = showcase_name

    def load(
        self,
        request: request_.GetShowcaseRequest,
    ) -> result_.GetShowcaseResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_showcase_name(self._showcase_name)
        r = self._client.get_showcase(
            request,
        )
        self._showcase_cache.update(r.item)
        return r

    def buy(
        self,
        request: request_.BuyRequest,
    ) -> result_.BuyResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_showcase_name(self._showcase_name)
        r = self._client.buy(
            request,
        )
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from inventory import Gs2InventoryRestClient, request as request_, result as result_
from inventory.domain.iterator.namespaces import DescribeNamespacesIterator
from inventory.domain.iterator.inventory_model_masters import DescribeInventoryModelMastersIterator
from inventory.domain.iterator.inventory_models import DescribeInventoryModelsIterator
from inventory.domain.iterator.item_model_masters import DescribeItemModelMastersIterator
from inventory.domain.iterator.item_models import DescribeItemModelsIterator
from inventory.domain.iterator.inventories import DescribeInventoriesIterator
from inventory.domain.iterator.inventories_by_user_id import DescribeInventoriesByUserIdIterator
from inventory.domain.iterator.item_sets import DescribeItemSetsIterator
from inventory.domain.iterator.item_sets_by_user_id import DescribeItemSetsByUserIdIterator
from inventory.domain.iterator.reference_of import DescribeReferenceOfIterator
from inventory.domain.iterator.reference_of_by_user_id import DescribeReferenceOfByUserIdIterator
from inventory.domain.cache.namespace import NamespaceDomainCache
from inventory.domain.cache.inventory_model_master import InventoryModelMasterDomainCache
from inventory.domain.cache.inventory_model import InventoryModelDomainCache
from inventory.domain.cache.item_model_master import ItemModelMasterDomainCache
from inventory.domain.cache.item_model import ItemModelDomainCache
from inventory.domain.cache.inventory import InventoryDomainCache
from inventory.domain.cache.item_set import ItemSetDomainCache
from inventory.domain.item_set import ItemSetDomain
from inventory.domain.item_set_access_token import ItemSetAccessTokenDomain
from inventory.domain.item_set_access_token import ItemSetAccessTokenDomain


class InventoryDomain:
    _session: Gs2RestSession
    _client: Gs2InventoryRestClient
    _inventory_cache: InventoryDomainCache
    _namespace_name: str
    _user_id: str
    _inventory_name: str
    _item_set_cache: ItemSetDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        inventory_cache: InventoryDomainCache,
        namespace_name: str,
        user_id: str,
        inventory_name: str,
    ):
        self._session = session
        self._client = Gs2InventoryRestClient(
            session,
        )
        self._inventory_cache = inventory_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._inventory_name = inventory_name
        self._item_set_cache = ItemSetDomainCache()

    def load(
        self,
        request: request_.GetInventoryByUserIdRequest,
    ) -> result_.GetInventoryByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_inventory_name(self._inventory_name)
        r = self._client.get_inventory_by_user_id(
            request,
        )
        self._inventory_cache.update(r.item)
        return r

    def add_capacity(
        self,
        request: request_.AddCapacityByUserIdRequest,
    ) -> result_.AddCapacityByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_inventory_name(self._inventory_name)
        r = self._client.add_capacity_by_user_id(
            request,
        )
        self._inventory_cache.update(r.item)
        return r

    def set_capacity(
        self,
        request: request_.SetCapacityByUserIdRequest,
    ) -> result_.SetCapacityByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_inventory_name(self._inventory_name)
        r = self._client.set_capacity_by_user_id(
            request,
        )
        self._inventory_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteInventoryByUserIdRequest,
    ) -> result_.DeleteInventoryByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_inventory_name(self._inventory_name)
        r = self._client.delete_inventory_by_user_id(
            request,
        )
        self._inventory_cache.delete(r.item)
        return r

    def item_sets(
        self,
    ) -> DescribeItemSetsByUserIdIterator:
        return DescribeItemSetsByUserIdIterator(
            self._item_set_cache,
            self._client,
            self._namespace_name,
            self._inventory_name,
            self._user_id,
        )

    def item_set(
        self,
        item_name: str,
        item_set_name: str,
    ) -> ItemSetDomain:
        return ItemSetDomain(
            self._session,
            self._item_set_cache,
            self._namespace_name,
            self._user_id,
            self._inventory_name,
            item_name,
            item_set_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from exchange import Gs2ExchangeRestClient, request as request_, result as result_
from exchange.domain.iterator.namespaces import DescribeNamespacesIterator
from exchange.domain.iterator.rate_models import DescribeRateModelsIterator
from exchange.domain.iterator.rate_model_masters import DescribeRateModelMastersIterator
from exchange.domain.iterator.awaits import DescribeAwaitsIterator
from exchange.domain.iterator.awaits_by_user_id import DescribeAwaitsByUserIdIterator
from exchange.domain.cache.namespace import NamespaceDomainCache
from exchange.domain.cache.rate_model import RateModelDomainCache
from exchange.domain.cache.rate_model_master import RateModelMasterDomainCache
from exchange.domain.cache.await_ import AwaitDomainCache
from exchange.domain.rate_model_master import RateModelMasterDomain
from exchange.domain.current_rate_master import CurrentRateMasterDomain
from exchange.domain.rate_model import RateModelDomain
from exchange.domain.user import UserDomain
from exchange.domain.user_access_token import UserAccessTokenDomain
from exchange.domain.user_access_token import UserAccessTokenDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2ExchangeRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _rate_model_cache: RateModelDomainCache
    _rate_model_master_cache: RateModelMasterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2ExchangeRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._rate_model_cache = RateModelDomainCache()
        self._rate_model_master_cache = RateModelMasterDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_rate_model_master(
        self,
        request: request_.CreateRateModelMasterRequest,
    ) -> result_.CreateRateModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_rate_model_master(
            request,
        )
        return r

    def rate_models(
        self,
    ) -> DescribeRateModelsIterator:
        return DescribeRateModelsIterator(
            self._rate_model_cache,
            self._client,
            self._namespace_name,
        )

    def rate_model_masters(
        self,
    ) -> DescribeRateModelMastersIterator:
        return DescribeRateModelMastersIterator(
            self._rate_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def rate_model_master(
        self,
        rate_name: str,
    ) -> RateModelMasterDomain:
        return RateModelMasterDomain(
            self._session,
            self._rate_model_master_cache,
            self._namespace_name,
            rate_name,
        )

    def current_rate_master(
        self,
    ) -> CurrentRateMasterDomain:
        return CurrentRateMasterDomain(
            self._session,
            self._namespace_name,
        )

    def rate_model(
        self,
        rate_name: str,
    ) -> RateModelDomain:
        return RateModelDomain(
            self._session,
            self._rate_model_cache,
            self._namespace_name,
            rate_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from matchmaking import Gs2MatchmakingRestClient, request as request_, result as result_
from matchmaking.domain.iterator.namespaces import DescribeNamespacesIterator
from matchmaking.domain.iterator.gatherings import DescribeGatheringsIterator
from matchmaking.domain.iterator.rating_model_masters import DescribeRatingModelMastersIterator
from matchmaking.domain.iterator.rating_models import DescribeRatingModelsIterator
from matchmaking.domain.iterator.ratings import DescribeRatingsIterator
from matchmaking.domain.iterator.ratings_by_user_id import DescribeRatingsByUserIdIterator
from matchmaking.domain.cache.namespace import NamespaceDomainCache
from matchmaking.domain.cache.gathering import GatheringDomainCache
from matchmaking.domain.cache.rating_model_master import RatingModelMasterDomainCache
from matchmaking.domain.cache.rating_model import RatingModelDomainCache
from matchmaking.domain.cache.rating import RatingDomainCache


class VoteAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2MatchmakingRestClient
    _namespace_name: str
    _access_token: AccessToken
    _rating_name: str
    _gathering_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
        rating_name: str,
        gathering_name: str,
    ):
        self._session = session
        self._client = Gs2MatchmakingRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._rating_name = rating_name
        self._gathering_name = gathering_name

    def get_ballot(
        self,
        request: request_.GetBallotRequest,
    ) -> result_.GetBallotResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_rating_name(self._rating_name)
        request.with_gathering_name(self._gathering_name)
        r = self._client.get_ballot(
            request,
        )
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from limit import Gs2LimitRestClient, request as request_, result as result_
from limit.domain.iterator.namespaces import DescribeNamespacesIterator
from limit.domain.iterator.counters import DescribeCountersIterator
from limit.domain.iterator.counters_by_user_id import DescribeCountersByUserIdIterator
from limit.domain.iterator.limit_model_masters import DescribeLimitModelMastersIterator
from limit.domain.iterator.limit_models import DescribeLimitModelsIterator
from limit.domain.cache.namespace import NamespaceDomainCache
from limit.domain.cache.counter import CounterDomainCache
from limit.domain.cache.limit_model_master import LimitModelMasterDomainCache
from limit.domain.cache.limit_model import LimitModelDomainCache


class CurrentLimitMasterDomain:
    _session: Gs2RestSession
    _client: Gs2LimitRestClient
    _namespace_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2LimitRestClient(
            session,
        )
        self._namespace_name = namespace_name

    def export_master(
        self,
        request: request_.ExportMasterRequest,
    ) -> result_.ExportMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.export_master(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetCurrentLimitMasterRequest,
    ) -> result_.GetCurrentLimitMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_current_limit_master(
            request,
        )
        return r

    def update(
        self,
        request: request_.UpdateCurrentLimitMasterRequest,
    ) -> result_.UpdateCurrentLimitMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_current_limit_master(
            request,
        )
        return r

    def update_from_git_hub(
        self,
        request: request_.UpdateCurrentLimitMasterFromGitHubRequest,
    ) -> result_.UpdateCurrentLimitMasterFromGitHubResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_current_limit_master_from_git_hub(
            request,
        )
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from inbox import Gs2InboxRestClient, request as request_, result as result_
from inbox.domain.iterator.namespaces import DescribeNamespacesIterator
from inbox.domain.iterator.messages import DescribeMessagesIterator
from inbox.domain.iterator.messages_by_user_id import DescribeMessagesByUserIdIterator
from inbox.domain.iterator.global_message_masters import DescribeGlobalMessageMastersIterator
from inbox.domain.iterator.global_messages import DescribeGlobalMessagesIterator
from inbox.domain.cache.namespace import NamespaceDomainCache
from inbox.domain.cache.message import MessageDomainCache
from inbox.domain.cache.global_message_master import GlobalMessageMasterDomainCache
from inbox.domain.cache.global_message import GlobalMessageDomainCache
from inbox.domain.user import UserDomain
from inbox.domain.user_access_token import UserAccessTokenDomain
from inbox.domain.user_access_token import UserAccessTokenDomain
from inbox.domain.current_message_master import CurrentMessageMasterDomain
from inbox.domain.global_message import GlobalMessageDomain
from inbox.domain.global_message_master import GlobalMessageMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2InboxRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _global_message_master_cache: GlobalMessageMasterDomainCache
    _global_message_cache: GlobalMessageDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2InboxRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._global_message_master_cache = GlobalMessageMasterDomainCache()
        self._global_message_cache = GlobalMessageDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_global_message_master(
        self,
        request: request_.CreateGlobalMessageMasterRequest,
    ) -> result_.CreateGlobalMessageMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_global_message_master(
            request,
        )
        return r

    def global_message_masters(
        self,
    ) -> DescribeGlobalMessageMastersIterator:
        return DescribeGlobalMessageMastersIterator(
            self._global_message_master_cache,
            self._client,
            self._namespace_name,
        )

    def global_messages(
        self,
    ) -> DescribeGlobalMessagesIterator:
        return DescribeGlobalMessagesIterator(
            self._global_message_cache,
            self._client,
            self._namespace_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def current_message_master(
        self,
    ) -> CurrentMessageMasterDomain:
        return CurrentMessageMasterDomain(
            self._session,
            self._namespace_name,
        )

    def global_message(
        self,
        global_message_name: str,
    ) -> GlobalMessageDomain:
        return GlobalMessageDomain(
            self._session,
            self._global_message_cache,
            self._namespace_name,
            global_message_name,
        )

    def global_message_master(
        self,
        global_message_name: str,
    ) -> GlobalMessageMasterDomain:
        return GlobalMessageMasterDomain(
            self._session,
            self._global_message_master_cache,
            self._namespace_name,
            global_message_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from inventory import Gs2InventoryRestClient, request as request_, result as result_
from inventory.domain.iterator.namespaces import DescribeNamespacesIterator
from inventory.domain.iterator.inventory_model_masters import DescribeInventoryModelMastersIterator
from inventory.domain.iterator.inventory_models import DescribeInventoryModelsIterator
from inventory.domain.iterator.item_model_masters import DescribeItemModelMastersIterator
from inventory.domain.iterator.item_models import DescribeItemModelsIterator
from inventory.domain.iterator.inventories import DescribeInventoriesIterator
from inventory.domain.iterator.inventories_by_user_id import DescribeInventoriesByUserIdIterator
from inventory.domain.iterator.item_sets import DescribeItemSetsIterator
from inventory.domain.iterator.item_sets_by_user_id import DescribeItemSetsByUserIdIterator
from inventory.domain.iterator.reference_of import DescribeReferenceOfIterator
from inventory.domain.iterator.reference_of_by_user_id import DescribeReferenceOfByUserIdIterator
from inventory.domain.cache.namespace import NamespaceDomainCache
from inventory.domain.cache.inventory_model_master import InventoryModelMasterDomainCache
from inventory.domain.cache.inventory_model import InventoryModelDomainCache
from inventory.domain.cache.item_model_master import ItemModelMasterDomainCache
from inventory.domain.cache.item_model import ItemModelDomainCache
from inventory.domain.cache.inventory import InventoryDomainCache
from inventory.domain.cache.item_set import ItemSetDomainCache
from inventory.domain.item_model_master import ItemModelMasterDomain


class InventoryModelMasterDomain:
    _session: Gs2RestSession
    _client: Gs2InventoryRestClient
    _inventory_model_master_cache: InventoryModelMasterDomainCache
    _namespace_name: str
    _inventory_name: str
    _item_model_master_cache: ItemModelMasterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        inventory_model_master_cache: InventoryModelMasterDomainCache,
        namespace_name: str,
        inventory_name: str,
    ):
        self._session = session
        self._client = Gs2InventoryRestClient(
            session,
        )
        self._inventory_model_master_cache = inventory_model_master_cache
        self._namespace_name = namespace_name
        self._inventory_name = inventory_name
        self._item_model_master_cache = ItemModelMasterDomainCache()

    def load(
        self,
        request: request_.GetInventoryModelMasterRequest,
    ) -> result_.GetInventoryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_inventory_name(self._inventory_name)
        r = self._client.get_inventory_model_master(
            request,
        )
        self._inventory_model_master_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateInventoryModelMasterRequest,
    ) -> result_.UpdateInventoryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_inventory_name(self._inventory_name)
        r = self._client.update_inventory_model_master(
            request,
        )
        self._inventory_model_master_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteInventoryModelMasterRequest,
    ) -> result_.DeleteInventoryModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_inventory_name(self._inventory_name)
        r = self._client.delete_inventory_model_master(
            request,
        )
        self._inventory_model_master_cache.delete(r.item)
        return r

    def create_item_model_master(
        self,
        request: request_.CreateItemModelMasterRequest,
    ) -> result_.CreateItemModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_inventory_name(self._inventory_name)
        r = self._client.create_item_model_master(
            request,
        )
        return r

    def item_model_masters(
        self,
    ) -> DescribeItemModelMastersIterator:
        return DescribeItemModelMastersIterator(
            self._item_model_master_cache,
            self._client,
            self._namespace_name,
            self._inventory_name,
        )

    def item_model_master(
        self,
        item_name: str,
    ) -> ItemModelMasterDomain:
        return ItemModelMasterDomain(
            self._session,
            self._item_model_master_cache,
            self._namespace_name,
            self._inventory_name,
            item_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from version import Gs2VersionRestClient, request as request_, result as result_
from version.domain.iterator.namespaces import DescribeNamespacesIterator
from version.domain.iterator.version_model_masters import DescribeVersionModelMastersIterator
from version.domain.iterator.version_models import DescribeVersionModelsIterator
from version.domain.iterator.accept_versions import DescribeAcceptVersionsIterator
from version.domain.iterator.accept_versions_by_user_id import DescribeAcceptVersionsByUserIdIterator
from version.domain.cache.namespace import NamespaceDomainCache
from version.domain.cache.version_model_master import VersionModelMasterDomainCache
from version.domain.cache.version_model import VersionModelDomainCache
from version.domain.cache.accept_version import AcceptVersionDomainCache


class VersionModelDomain:
    _session: Gs2RestSession
    _client: Gs2VersionRestClient
    _version_model_cache: VersionModelDomainCache
    _namespace_name: str
    _version_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        version_model_cache: VersionModelDomainCache,
        namespace_name: str,
        version_name: str,
    ):
        self._session = session
        self._client = Gs2VersionRestClient(
            session,
        )
        self._version_model_cache = version_model_cache
        self._namespace_name = namespace_name
        self._version_name = version_name

    def load(
        self,
        request: request_.GetVersionModelRequest,
    ) -> result_.GetVersionModelResult:
        request.with_namespace_name(self._namespace_name)
        request.with_version_name(self._version_name)
        r = self._client.get_version_model(
            request,
        )
        self._version_model_cache.update(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from schedule import Gs2ScheduleRestClient, request as request_, result as result_
from schedule.domain.iterator.namespaces import DescribeNamespacesIterator
from schedule.domain.iterator.event_masters import DescribeEventMastersIterator
from schedule.domain.iterator.triggers import DescribeTriggersIterator
from schedule.domain.iterator.triggers_by_user_id import DescribeTriggersByUserIdIterator
from schedule.domain.iterator.events import DescribeEventsIterator
from schedule.domain.iterator.events_by_user_id import DescribeEventsByUserIdIterator
from schedule.domain.iterator.raw_events import DescribeRawEventsIterator
from schedule.domain.cache.namespace import NamespaceDomainCache
from schedule.domain.cache.event_master import EventMasterDomainCache
from schedule.domain.cache.trigger import TriggerDomainCache
from schedule.domain.cache.event import EventDomainCache
from schedule.domain.user import UserDomain
from schedule.domain.user_access_token import UserAccessTokenDomain
from schedule.domain.user_access_token import UserAccessTokenDomain
from schedule.domain.current_event_master import CurrentEventMasterDomain
from schedule.domain.event_master import EventMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2ScheduleRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _event_master_cache: EventMasterDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2ScheduleRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._event_master_cache = EventMasterDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_event_master(
        self,
        request: request_.CreateEventMasterRequest,
    ) -> result_.CreateEventMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_event_master(
            request,
        )
        return r

    def event_masters(
        self,
    ) -> DescribeEventMastersIterator:
        return DescribeEventMastersIterator(
            self._event_master_cache,
            self._client,
            self._namespace_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def current_event_master(
        self,
    ) -> CurrentEventMasterDomain:
        return CurrentEventMasterDomain(
            self._session,
            self._namespace_name,
        )

    def event_master(
        self,
        event_name: str,
    ) -> EventMasterDomain:
        return EventMasterDomain(
            self._session,
            self._event_master_cache,
            self._namespace_name,
            event_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from datastore import Gs2DatastoreRestClient, request as request_, result as result_
from datastore.domain.iterator.namespaces import DescribeNamespacesIterator
from datastore.domain.iterator.data_objects import DescribeDataObjectsIterator
from datastore.domain.iterator.data_objects_by_user_id import DescribeDataObjectsByUserIdIterator
from datastore.domain.iterator.data_object_histories import DescribeDataObjectHistoriesIterator
from datastore.domain.iterator.data_object_histories_by_user_id import DescribeDataObjectHistoriesByUserIdIterator
from datastore.domain.cache.namespace import NamespaceDomainCache
from datastore.domain.cache.data_object import DataObjectDomainCache
from datastore.domain.cache.data_object_history import DataObjectHistoryDomainCache
from datastore.domain.data_object import DataObjectDomain
from datastore.domain.data_object_access_token import DataObjectAccessTokenDomain
from datastore.domain.data_object_access_token import DataObjectAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2DatastoreRestClient
    _namespace_name: str
    _access_token: AccessToken
    _data_object_cache: DataObjectDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2DatastoreRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._data_object_cache = DataObjectDomainCache()

    def prepare_upload(
        self,
        request: request_.PrepareUploadRequest,
    ) -> result_.PrepareUploadResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_upload(
            request,
        )
        return r

    def prepare_re_upload(
        self,
        request: request_.PrepareReUploadRequest,
    ) -> result_.PrepareReUploadResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_re_upload(
            request,
        )
        return r

    def prepare_download(
        self,
        request: request_.PrepareDownloadRequest,
    ) -> result_.PrepareDownloadResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_download(
            request,
        )
        return r

    def prepare_download_by_generation(
        self,
        request: request_.PrepareDownloadByGenerationRequest,
    ) -> result_.PrepareDownloadByGenerationResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_download_by_generation(
            request,
        )
        return r

    def prepare_download_own_data(
        self,
        request: request_.PrepareDownloadOwnDataRequest,
    ) -> result_.PrepareDownloadOwnDataResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_download_own_data(
            request,
        )
        return r

    def prepare_download_own_data_by_generation(
        self,
        request: request_.PrepareDownloadOwnDataByGenerationRequest,
    ) -> result_.PrepareDownloadOwnDataByGenerationResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.prepare_download_own_data_by_generation(
            request,
        )
        return r

    def data_objects(
        self,
        status: str,
    ) -> DescribeDataObjectsIterator:
        return DescribeDataObjectsIterator(
            self._data_object_cache,
            self._client,
            self._namespace_name,
            self._access_token,
            status,
        )

    def data_object(
        self,
        data_object_name: str,
    ) -> DataObjectAccessTokenDomain:
        return DataObjectAccessTokenDomain(
            self._session,
            self._data_object_cache,
            self._namespace_name,
            self._access_token,
            data_object_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
#
# deny overwrite

from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from auth import Gs2AuthRestClient, request as request_, result as result_


class AccessTokenDomain:

    def __init__(
        self,
        session: Gs2RestSession,
    ):
        self._session = session
        self._client = Gs2AuthRestClient(
            session=session,
        )

    def login(
            self,
            request: request_.LoginRequest,
    ) -> AccessToken:

        result = self._client.login(
            request
        )
        return AccessToken(
            user_id=result.user_id,
            token=result.token,
            expire=result.expire,
        )

    def login_by_signature(
            self,
            request: request_.LoginBySignatureRequest,
    ) -> AccessToken:

        result = self._client.login_by_signature(
            request
        )
        return AccessToken(
            user_id=result.user_id,
            token=result.token,
            expire=result.expire,
        )




# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from friend import Gs2FriendRestClient, request as request_, result as result_
from friend.domain.iterator.namespaces import DescribeNamespacesIterator
from friend.domain.iterator.follows import DescribeFollowsIterator
from friend.domain.iterator.follows_by_user_id import DescribeFollowsByUserIdIterator
from friend.domain.iterator.friends import DescribeFriendsIterator
from friend.domain.iterator.friends_by_user_id import DescribeFriendsByUserIdIterator
from friend.domain.iterator.send_requests import DescribeSendRequestsIterator
from friend.domain.iterator.send_requests_by_user_id import DescribeSendRequestsByUserIdIterator
from friend.domain.iterator.receive_requests import DescribeReceiveRequestsIterator
from friend.domain.iterator.receive_requests_by_user_id import DescribeReceiveRequestsByUserIdIterator
from friend.domain.iterator.black_list import DescribeBlackListIterator
from friend.domain.iterator.black_list_by_user_id import DescribeBlackListByUserIdIterator
from friend.domain.cache.namespace import NamespaceDomainCache
from friend.domain.cache.follow_user import FollowUserDomainCache
from friend.domain.cache.friend_user import FriendUserDomainCache
from friend.domain.cache.friend_request import FriendRequestDomainCache
from friend.domain.profile import ProfileDomain
from friend.domain.profile_access_token import ProfileAccessTokenDomain
from friend.domain.profile_access_token import ProfileAccessTokenDomain
from friend.domain.black_list import BlackListDomain
from friend.domain.black_list_access_token import BlackListAccessTokenDomain
from friend.domain.black_list_access_token import BlackListAccessTokenDomain
from friend.domain.follow import FollowDomain
from friend.domain.follow_access_token import FollowAccessTokenDomain
from friend.domain.follow_access_token import FollowAccessTokenDomain
from friend.domain.friend import FriendDomain
from friend.domain.friend_access_token import FriendAccessTokenDomain
from friend.domain.friend_access_token import FriendAccessTokenDomain
from friend.domain.send_box import SendBoxDomain
from friend.domain.send_box_access_token import SendBoxAccessTokenDomain
from friend.domain.send_box_access_token import SendBoxAccessTokenDomain
from friend.domain.inbox import InboxDomain
from friend.domain.inbox_access_token import InboxAccessTokenDomain
from friend.domain.inbox_access_token import InboxAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2FriendRestClient
    _namespace_name: str
    _access_token: AccessToken
    _follow_user_cache: FollowUserDomainCache
    _friend_user_cache: FriendUserDomainCache
    _friend_request_cache: FriendRequestDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2FriendRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._follow_user_cache = FollowUserDomainCache()
        self._friend_user_cache = FriendUserDomainCache()
        self._friend_request_cache = FriendRequestDomainCache()

    def profile(
        self,
    ) -> ProfileAccessTokenDomain:
        return ProfileAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )

    def black_list(
        self,
    ) -> BlackListAccessTokenDomain:
        return BlackListAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )

    def follow(
        self,
    ) -> FollowAccessTokenDomain:
        return FollowAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )

    def friend(
        self,
    ) -> FriendAccessTokenDomain:
        return FriendAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )

    def send_box(
        self,
    ) -> SendBoxAccessTokenDomain:
        return SendBoxAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )

    def inbox(
        self,
    ) -> InboxAccessTokenDomain:
        return InboxAccessTokenDomain(
            self._session,
            self._namespace_name,
            self._access_token,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from friend import Gs2FriendRestClient, request as request_, result as result_
from friend.domain.iterator.namespaces import DescribeNamespacesIterator
from friend.domain.iterator.follows import DescribeFollowsIterator
from friend.domain.iterator.follows_by_user_id import DescribeFollowsByUserIdIterator
from friend.domain.iterator.friends import DescribeFriendsIterator
from friend.domain.iterator.friends_by_user_id import DescribeFriendsByUserIdIterator
from friend.domain.iterator.send_requests import DescribeSendRequestsIterator
from friend.domain.iterator.send_requests_by_user_id import DescribeSendRequestsByUserIdIterator
from friend.domain.iterator.receive_requests import DescribeReceiveRequestsIterator
from friend.domain.iterator.receive_requests_by_user_id import DescribeReceiveRequestsByUserIdIterator
from friend.domain.iterator.black_list import DescribeBlackListIterator
from friend.domain.iterator.black_list_by_user_id import DescribeBlackListByUserIdIterator
from friend.domain.cache.namespace import NamespaceDomainCache
from friend.domain.cache.follow_user import FollowUserDomainCache
from friend.domain.cache.friend_user import FriendUserDomainCache
from friend.domain.cache.friend_request import FriendRequestDomainCache


class SendBoxDomain:
    _session: Gs2RestSession
    _client: Gs2FriendRestClient
    _friend_request_cache: FriendRequestDomainCache
    _namespace_name: str
    _user_id: str

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2FriendRestClient(
            session,
        )
        self._friend_request_cache = FriendRequestDomainCache()
        self._namespace_name = namespace_name
        self._user_id = user_id

    def get_send_request(
        self,
        request: request_.GetSendRequestByUserIdRequest,
    ) -> result_.GetSendRequestByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.get_send_request_by_user_id(
            request,
        )
        return r

    def send_request(
        self,
        request: request_.SendRequestByUserIdRequest,
    ) -> result_.SendRequestByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.send_request_by_user_id(
            request,
        )
        return r

    def delete_request(
        self,
        request: request_.DeleteRequestByUserIdRequest,
    ) -> result_.DeleteRequestByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        r = self._client.delete_request_by_user_id(
            request,
        )
        return r

    def list(
        self,
    ) -> DescribeSendRequestsByUserIdIterator:
        return DescribeSendRequestsByUserIdIterator(
            self._friend_request_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from datastore import Gs2DatastoreRestClient, request as request_, result as result_
from datastore.domain.iterator.namespaces import DescribeNamespacesIterator
from datastore.domain.iterator.data_objects import DescribeDataObjectsIterator
from datastore.domain.iterator.data_objects_by_user_id import DescribeDataObjectsByUserIdIterator
from datastore.domain.iterator.data_object_histories import DescribeDataObjectHistoriesIterator
from datastore.domain.iterator.data_object_histories_by_user_id import DescribeDataObjectHistoriesByUserIdIterator
from datastore.domain.cache.namespace import NamespaceDomainCache
from datastore.domain.cache.data_object import DataObjectDomainCache
from datastore.domain.cache.data_object_history import DataObjectHistoryDomainCache
from datastore.domain.data_object_history import DataObjectHistoryDomain
from datastore.domain.data_object_history_access_token import DataObjectHistoryAccessTokenDomain
from datastore.domain.data_object_history_access_token import DataObjectHistoryAccessTokenDomain


class DataObjectDomain:
    _session: Gs2RestSession
    _client: Gs2DatastoreRestClient
    _data_object_cache: DataObjectDomainCache
    _namespace_name: str
    _user_id: str
    _data_object_name: str
    _data_object_history_cache: DataObjectHistoryDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        data_object_cache: DataObjectDomainCache,
        namespace_name: str,
        user_id: str,
        data_object_name: str,
    ):
        self._session = session
        self._client = Gs2DatastoreRestClient(
            session,
        )
        self._data_object_cache = data_object_cache
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._data_object_name = data_object_name
        self._data_object_history_cache = DataObjectHistoryDomainCache()

    def update(
        self,
        request: request_.UpdateDataObjectByUserIdRequest,
    ) -> result_.UpdateDataObjectByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_data_object_name(self._data_object_name)
        r = self._client.update_data_object_by_user_id(
            request,
        )
        self._data_object_cache.update(r.item)
        return r

    def done_upload(
        self,
        request: request_.DoneUploadByUserIdRequest,
    ) -> result_.DoneUploadByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_data_object_name(self._data_object_name)
        r = self._client.done_upload_by_user_id(
            request,
        )
        self._data_object_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteDataObjectByUserIdRequest,
    ) -> result_.DeleteDataObjectByUserIdResult:
        request.with_namespace_name(self._namespace_name)
        request.with_user_id(self._user_id)
        request.with_data_object_name(self._data_object_name)
        r = self._client.delete_data_object_by_user_id(
            request,
        )
        self._data_object_cache.delete(r.item)
        return r

    def data_object_histories(
        self,
    ) -> DescribeDataObjectHistoriesByUserIdIterator:
        return DescribeDataObjectHistoriesByUserIdIterator(
            self._data_object_history_cache,
            self._client,
            self._namespace_name,
            self._user_id,
            self._data_object_name,
        )

    def data_object_history(
        self,
        generation: str,
    ) -> DataObjectHistoryDomain:
        return DataObjectHistoryDomain(
            self._session,
            self._data_object_history_cache,
            self._namespace_name,
            self._user_id,
            self._data_object_name,
            generation,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
#
# deny overwrite

from __future__ import annotations

from core import Gs2RestSession
from identifier import Gs2IdentifierRestClient, request as request_, result as result_
from identifier.domain.iterator.users import DescribeUsersIterator
from identifier.domain.iterator.security_policies import DescribeSecurityPoliciesIterator
from identifier.domain.iterator.common_security_policies import DescribeCommonSecurityPoliciesIterator
from identifier.domain.cache.user import UserDomainCache
from identifier.domain.cache.security_policy import SecurityPolicyDomainCache
from identifier.domain.user import UserDomain
from identifier.domain.security_policy import SecurityPolicyDomain


class Gs2Identifier:

    def __init__(
        self,
        session: Gs2RestSession,
    ):
        self._session = session
        self._client = Gs2IdentifierRestClient(
            session=session,
        )
        self._user_cache = UserDomainCache()
        self._security_policy_cache = SecurityPolicyDomainCache()

    def create_user(
        self,
        request: request_.CreateUserRequest,
    ) -> result_.CreateUserResult:
        r = self._client.create_user(
            request=request,
        )
        self._user_cache.update(r.item)
        return r

    def update_user(
        self,
        request: request_.UpdateUserRequest,
    ) -> result_.UpdateUserResult:
        r = self._client.update_user(
            request=request,
        )
        self._user_cache.update(r.item)
        return r

    def delete_user(
        self,
        request: request_.DeleteUserRequest,
    ) -> result_.DeleteUserResult:
        r = self._client.delete_user(
            request=request,
        )
        return r

    def create_security_policy(
        self,
        request: request_.CreateSecurityPolicyRequest,
    ) -> result_.CreateSecurityPolicyResult:
        r = self._client.create_security_policy(
            request=request,
        )
        self._security_policy_cache.update(r.item)
        return r

    def update_security_policy(
        self,
        request: request_.UpdateSecurityPolicyRequest,
    ) -> result_.UpdateSecurityPolicyResult:
        r = self._client.update_security_policy(
            request=request,
        )
        self._security_policy_cache.update(r.item)
        return r

    def delete_security_policy(
        self,
        request: request_.DeleteSecurityPolicyRequest,
    ) -> result_.DeleteSecurityPolicyResult:
        r = self._client.delete_security_policy(
            request=request,
        )
        return r

    def create_identifier(
        self,
        request: request_.CreateIdentifierRequest,
    ) -> result_.CreateIdentifierResult:
        r = self._client.create_identifier(
            request=request,
        )
        return r

    def delete_identifier(
        self,
        request: request_.DeleteIdentifierRequest,
    ) -> result_.DeleteIdentifierResult:
        r = self._client.delete_identifier(
            request=request,
        )
        return r

    def login(
        self,
        request: request_.LoginRequest,
    ) -> result_.LoginResult:
        r = self._client.login(
            request=request,
        )
        return r

    def login_by_user(
        self,
        request: request_.LoginByUserRequest,
    ) -> result_.LoginByUserResult:
        r = self._client.login_by_user(
            request=request,
        )
        return r

    def users(
        self,
    ) -> DescribeUsersIterator:
        return DescribeUsersIterator(
            user_cache=self._user_cache,
            client=self._client,
        )

    def security_policies(
        self,
    ) -> DescribeSecurityPoliciesIterator:
        return DescribeSecurityPoliciesIterator(
            security_policy_cache=self._security_policy_cache,
            client=self._client,
        )

    def common_security_policies(
        self,
    ) -> DescribeCommonSecurityPoliciesIterator:
        return DescribeCommonSecurityPoliciesIterator(
            security_policy_cache=self._security_policy_cache,
            client=self._client,
        )

    def user(
        self,
        user_name: str,
    ) -> UserDomain:
        return UserDomain(
            session=self._session,
            user_cache=self._user_cache,
            user_name=user_name,
        )

    def security_policy(
        self,
        security_policy_name: str,
    ) -> SecurityPolicyDomain:
        return SecurityPolicyDomain(
            session=self._session,
            security_policy_cache=self._security_policy_cache,
            security_policy_name=security_policy_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from enhance import Gs2EnhanceRestClient, request as request_, result as result_
from enhance.domain.iterator.namespaces import DescribeNamespacesIterator
from enhance.domain.iterator.rate_models import DescribeRateModelsIterator
from enhance.domain.iterator.rate_model_masters import DescribeRateModelMastersIterator
from enhance.domain.iterator.progresses_by_user_id import DescribeProgressesByUserIdIterator
from enhance.domain.cache.namespace import NamespaceDomainCache
from enhance.domain.cache.rate_model import RateModelDomainCache
from enhance.domain.cache.rate_model_master import RateModelMasterDomainCache
from enhance.domain.cache.progress import ProgressDomainCache


class RateModelMasterDomain:
    _session: Gs2RestSession
    _client: Gs2EnhanceRestClient
    _rate_model_master_cache: RateModelMasterDomainCache
    _namespace_name: str
    _rate_name: str

    def __init__(
        self,
        session: Gs2RestSession,
        rate_model_master_cache: RateModelMasterDomainCache,
        namespace_name: str,
        rate_name: str,
    ):
        self._session = session
        self._client = Gs2EnhanceRestClient(
            session,
        )
        self._rate_model_master_cache = rate_model_master_cache
        self._namespace_name = namespace_name
        self._rate_name = rate_name

    def load(
        self,
        request: request_.GetRateModelMasterRequest,
    ) -> result_.GetRateModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_rate_name(self._rate_name)
        r = self._client.get_rate_model_master(
            request,
        )
        self._rate_model_master_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateRateModelMasterRequest,
    ) -> result_.UpdateRateModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_rate_name(self._rate_name)
        r = self._client.update_rate_model_master(
            request,
        )
        self._rate_model_master_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteRateModelMasterRequest,
    ) -> result_.DeleteRateModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        request.with_rate_name(self._rate_name)
        r = self._client.delete_rate_model_master(
            request,
        )
        self._rate_model_master_cache.delete(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from quest import Gs2QuestRestClient, request as request_, result as result_
from quest.domain.iterator.namespaces import DescribeNamespacesIterator
from quest.domain.iterator.quest_group_model_masters import DescribeQuestGroupModelMastersIterator
from quest.domain.iterator.quest_model_masters import DescribeQuestModelMastersIterator
from quest.domain.iterator.progresses_by_user_id import DescribeProgressesByUserIdIterator
from quest.domain.iterator.completed_quest_lists import DescribeCompletedQuestListsIterator
from quest.domain.iterator.completed_quest_lists_by_user_id import DescribeCompletedQuestListsByUserIdIterator
from quest.domain.iterator.quest_group_models import DescribeQuestGroupModelsIterator
from quest.domain.iterator.quest_models import DescribeQuestModelsIterator
from quest.domain.cache.namespace import NamespaceDomainCache
from quest.domain.cache.quest_group_model_master import QuestGroupModelMasterDomainCache
from quest.domain.cache.quest_model_master import QuestModelMasterDomainCache
from quest.domain.cache.progress import ProgressDomainCache
from quest.domain.cache.completed_quest_list import CompletedQuestListDomainCache
from quest.domain.cache.quest_group_model import QuestGroupModelDomainCache
from quest.domain.cache.quest_model import QuestModelDomainCache
from quest.domain.progress import ProgressDomain
from quest.domain.progress_access_token import ProgressAccessTokenDomain
from quest.domain.progress_access_token import ProgressAccessTokenDomain
from quest.domain.completed_quest_list import CompletedQuestListDomain
from quest.domain.completed_quest_list_access_token import CompletedQuestListAccessTokenDomain
from quest.domain.completed_quest_list_access_token import CompletedQuestListAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2QuestRestClient
    _namespace_name: str
    _access_token: AccessToken
    _progress_cache: ProgressDomainCache
    _completed_quest_list_cache: CompletedQuestListDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2QuestRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._progress_cache = ProgressDomainCache()
        self._completed_quest_list_cache = CompletedQuestListDomainCache()

    def completed_quest_lists(
        self,
    ) -> DescribeCompletedQuestListsIterator:
        return DescribeCompletedQuestListsIterator(
            self._completed_quest_list_cache,
            self._client,
            self._namespace_name,
            self._access_token,
        )

    def progress(
        self,
    ) -> ProgressAccessTokenDomain:
        return ProgressAccessTokenDomain(
            self._session,
            self._progress_cache,
            self._namespace_name,
            self._access_token,
        )

    def completed_quest_list(
        self,
        quest_group_name: str,
    ) -> CompletedQuestListAccessTokenDomain:
        return CompletedQuestListAccessTokenDomain(
            self._session,
            self._completed_quest_list_cache,
            self._namespace_name,
            self._access_token,
            quest_group_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from quest import Gs2QuestRestClient, request as request_, result as result_
from quest.domain.iterator.namespaces import DescribeNamespacesIterator
from quest.domain.iterator.quest_group_model_masters import DescribeQuestGroupModelMastersIterator
from quest.domain.iterator.quest_model_masters import DescribeQuestModelMastersIterator
from quest.domain.iterator.progresses_by_user_id import DescribeProgressesByUserIdIterator
from quest.domain.iterator.completed_quest_lists import DescribeCompletedQuestListsIterator
from quest.domain.iterator.completed_quest_lists_by_user_id import DescribeCompletedQuestListsByUserIdIterator
from quest.domain.iterator.quest_group_models import DescribeQuestGroupModelsIterator
from quest.domain.iterator.quest_models import DescribeQuestModelsIterator
from quest.domain.cache.namespace import NamespaceDomainCache
from quest.domain.cache.quest_group_model_master import QuestGroupModelMasterDomainCache
from quest.domain.cache.quest_model_master import QuestModelMasterDomainCache
from quest.domain.cache.progress import ProgressDomainCache
from quest.domain.cache.completed_quest_list import CompletedQuestListDomainCache
from quest.domain.cache.quest_group_model import QuestGroupModelDomainCache
from quest.domain.cache.quest_model import QuestModelDomainCache
from quest.domain.user import UserDomain
from quest.domain.user_access_token import UserAccessTokenDomain
from quest.domain.user_access_token import UserAccessTokenDomain
from quest.domain.current_quest_master import CurrentQuestMasterDomain
from quest.domain.quest_group_model import QuestGroupModelDomain
from quest.domain.quest_group_model_master import QuestGroupModelMasterDomain


class NamespaceDomain:
    _session: Gs2RestSession
    _client: Gs2QuestRestClient
    _namespace_cache: NamespaceDomainCache
    _namespace_name: str
    _quest_group_model_master_cache: QuestGroupModelMasterDomainCache
    _quest_group_model_cache: QuestGroupModelDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_cache: NamespaceDomainCache,
        namespace_name: str,
    ):
        self._session = session
        self._client = Gs2QuestRestClient(
            session,
        )
        self._namespace_cache = namespace_cache
        self._namespace_name = namespace_name
        self._quest_group_model_master_cache = QuestGroupModelMasterDomainCache()
        self._quest_group_model_cache = QuestGroupModelDomainCache()

    def get_status(
        self,
        request: request_.GetNamespaceStatusRequest,
    ) -> result_.GetNamespaceStatusResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace_status(
            request,
        )
        return r

    def load(
        self,
        request: request_.GetNamespaceRequest,
    ) -> result_.GetNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.get_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateNamespaceRequest,
    ) -> result_.UpdateNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.update_namespace(
            request,
        )
        self._namespace_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteNamespaceRequest,
    ) -> result_.DeleteNamespaceResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.delete_namespace(
            request,
        )
        self._namespace_cache.delete(r.item)
        return r

    def create_quest_group_model_master(
        self,
        request: request_.CreateQuestGroupModelMasterRequest,
    ) -> result_.CreateQuestGroupModelMasterResult:
        request.with_namespace_name(self._namespace_name)
        r = self._client.create_quest_group_model_master(
            request,
        )
        return r

    def quest_group_model_masters(
        self,
    ) -> DescribeQuestGroupModelMastersIterator:
        return DescribeQuestGroupModelMastersIterator(
            self._quest_group_model_master_cache,
            self._client,
            self._namespace_name,
        )

    def quest_group_models(
        self,
    ) -> DescribeQuestGroupModelsIterator:
        return DescribeQuestGroupModelsIterator(
            self._quest_group_model_cache,
            self._client,
            self._namespace_name,
        )

    def user(
        self,
        user_id: str,
    ) -> UserDomain:
        return UserDomain(
            self._session,
            self._namespace_name,
            user_id,
        )

    def access_token(
        self,
        access_token: AccessToken,
    ) -> UserAccessTokenDomain:
        return UserAccessTokenDomain(
            self._session,
            self._namespace_name,
            access_token,
        )

    def current_quest_master(
        self,
    ) -> CurrentQuestMasterDomain:
        return CurrentQuestMasterDomain(
            self._session,
            self._namespace_name,
        )

    def quest_group_model(
        self,
        quest_group_name: str,
    ) -> QuestGroupModelDomain:
        return QuestGroupModelDomain(
            self._session,
            self._quest_group_model_cache,
            self._namespace_name,
            quest_group_name,
        )

    def quest_group_model_master(
        self,
        quest_group_name: str,
    ) -> QuestGroupModelMasterDomain:
        return QuestGroupModelMasterDomain(
            self._session,
            self._quest_group_model_master_cache,
            self._namespace_name,
            quest_group_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from chat import Gs2ChatRestClient, request as request_, result as result_
from chat.domain.iterator.namespaces import DescribeNamespacesIterator
from chat.domain.iterator.rooms import DescribeRoomsIterator
from chat.domain.iterator.messages import DescribeMessagesIterator
from chat.domain.iterator.messages_by_user_id import DescribeMessagesByUserIdIterator
from chat.domain.iterator.subscribes import DescribeSubscribesIterator
from chat.domain.iterator.subscribes_by_user_id import DescribeSubscribesByUserIdIterator
from chat.domain.iterator.subscribes_by_room_name import DescribeSubscribesByRoomNameIterator
from chat.domain.cache.namespace import NamespaceDomainCache
from chat.domain.cache.room import RoomDomainCache
from chat.domain.cache.message import MessageDomainCache
from chat.domain.cache.subscribe import SubscribeDomainCache
from chat.domain.room import RoomDomain
from chat.domain.room_access_token import RoomAccessTokenDomain
from chat.domain.room_access_token import RoomAccessTokenDomain
from chat.domain.subscribe import SubscribeDomain
from chat.domain.subscribe_access_token import SubscribeAccessTokenDomain
from chat.domain.subscribe_access_token import SubscribeAccessTokenDomain


class UserAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2ChatRestClient
    _namespace_name: str
    _access_token: AccessToken
    _room_cache: RoomDomainCache
    _subscribe_cache: SubscribeDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        access_token: AccessToken,
    ):
        self._session = session
        self._client = Gs2ChatRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._room_cache = RoomDomainCache()
        self._subscribe_cache = SubscribeDomainCache()

    def create_room(
        self,
        request: request_.CreateRoomRequest,
    ) -> result_.CreateRoomResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        r = self._client.create_room(
            request,
        )
        return r

    def subscribes(
        self,
    ) -> DescribeSubscribesIterator:
        return DescribeSubscribesIterator(
            self._subscribe_cache,
            self._client,
            self._namespace_name,
            self._access_token,
        )

    def room(
        self,
        room_name: str,
        password: str,
    ) -> RoomAccessTokenDomain:
        return RoomAccessTokenDomain(
            self._session,
            self._room_cache,
            self._namespace_name,
            self._access_token,
            room_name,
            password,
        )

    def subscribe(
        self,
        room_name: str,
    ) -> SubscribeAccessTokenDomain:
        return SubscribeAccessTokenDomain(
            self._session,
            self._subscribe_cache,
            self._namespace_name,
            self._access_token,
            room_name,
        )



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from account import Gs2AccountRestClient, request as request_, result as result_
from account.domain.iterator.namespaces import DescribeNamespacesIterator
from account.domain.iterator.accounts import DescribeAccountsIterator
from account.domain.iterator.take_overs import DescribeTakeOversIterator
from account.domain.iterator.take_overs_by_user_id import DescribeTakeOversByUserIdIterator
from account.domain.cache.namespace import NamespaceDomainCache
from account.domain.cache.account import AccountDomainCache
from account.domain.cache.take_over import TakeOverDomainCache


class TakeOverAccessTokenDomain:
    _session: Gs2RestSession
    _client: Gs2AccountRestClient
    _take_over_cache: TakeOverDomainCache
    _namespace_name: str
    _access_token: AccessToken
    _type_: int

    def __init__(
        self,
        session: Gs2RestSession,
        take_over_cache: TakeOverDomainCache,
        namespace_name: str,
        access_token: AccessToken,
        type_: int,
    ):
        self._session = session
        self._client = Gs2AccountRestClient(
            session,
        )
        self._take_over_cache = take_over_cache
        self._namespace_name = namespace_name
        self._access_token = access_token
        self._type_ = type_

    def load(
        self,
        request: request_.GetTakeOverRequest,
    ) -> result_.GetTakeOverResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_type(self._type_)
        r = self._client.get_take_over(
            request,
        )
        self._take_over_cache.update(r.item)
        return r

    def update(
        self,
        request: request_.UpdateTakeOverRequest,
    ) -> result_.UpdateTakeOverResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_type(self._type_)
        r = self._client.update_take_over(
            request,
        )
        self._take_over_cache.update(r.item)
        return r

    def delete(
        self,
        request: request_.DeleteTakeOverRequest,
    ) -> result_.DeleteTakeOverResult:
        request.with_namespace_name(self._namespace_name)
        request.with_access_token(self._access_token.token if self._access_token else None)
        request.with_type(self._type_)
        r = self._client.delete_take_over(
            request,
        )
        self._take_over_cache.delete(r.item)
        return r



# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations

from core import Gs2RestSession
from core.domain.access_token import AccessToken
from lock import Gs2LockRestClient, request as request_, result as result_
from lock.domain.iterator.namespaces import DescribeNamespacesIterator
from lock.domain.iterator.mutexes import DescribeMutexesIterator
from lock.domain.iterator.mutexes_by_user_id import DescribeMutexesByUserIdIterator
from lock.domain.cache.namespace import NamespaceDomainCache
from lock.domain.cache.mutex import MutexDomainCache
from lock.domain.mutex import MutexDomain
from lock.domain.mutex_access_token import MutexAccessTokenDomain
from lock.domain.mutex_access_token import MutexAccessTokenDomain


class UserDomain:
    _session: Gs2RestSession
    _client: Gs2LockRestClient
    _namespace_name: str
    _user_id: str
    _mutex_cache: MutexDomainCache

    def __init__(
        self,
        session: Gs2RestSession,
        namespace_name: str,
        user_id: str,
    ):
        self._session = session
        self._client = Gs2LockRestClient(
            session,
        )
        self._namespace_name = namespace_name
        self._user_id = user_id
        self._mutex_cache = MutexDomainCache()

    def mutexes(
        self,
    ) -> DescribeMutexesByUserIdIterator:
        return DescribeMutexesByUserIdIterator(
            self._mutex_cache,
            self._client,
            self._namespace_name,
            self._user_id,
        )

    def mutex(
        self,
        property_id: str,
    ) -> MutexDomain:
        return MutexDomain(
            self._session,
            self._mutex_cache,
            self._namespace_name,
            self._user_id,
            property_id,
        )
